@@ -13,7 +13,7 @@ class UserService(AbstractModelService):
         try:
             return cls._model.objects.get(username=attrs.get("username"))
         except cls._model.DoesNotExist:
-            return cls._model.objects.create(**attrs)
+            return cls.create(**attrs)
 
     @classmethod
     def create(cls, **attrs) -> models.Model:
