@@ -97,25 +97,31 @@ class ViewSet(viewsets.ViewSet):
         params = {**default, **params}
         return self.get_response(data, **params)
 
-    def get_validated_data(self, serializer_key=None):
+    # def get_validated_data(self, serializer_key=None, serializer_args=None):
+    def get_validated_data(self, **kwargs):
         """
-        Validate request data (throw exception if invalid) and return validated data
+        Validate request data (throw exception if invalid) and return validated data.
 
         Args:
-            serializer_key(None|str): serializer to use,
-                default is "<action name>_validation"
-
+            kwargs: supported values are :
+                    - serializer_key(None|str): serializer to use,
+                        if not provided default is "<action name>_validation"
+                    - context(None|dict): to pass context to serializer
+                        (in the methods of the serializer, the context can be accessed
+                         with statement "self.context")
+                    - many(bool): True for list usage, False by default
         Returns:
             dict
         """
+        serializer_key = kwargs.pop("serializer_key", None)
         if serializer_key is None:
             serializer_key = f"{self.action}_validation"
         if serializer_key not in self.serializers:
             raise RuntimeError(f"You need to define '{serializer_key}' serializer")
         serializer_class = self.get_serializer_class(serializer_key)
-        serializer = serializer_class(data=self.request.data)
+        serializer = serializer_class(data=self.request.data, **kwargs)
         if self.request.query_params and not self.request.data:
-            serializer = serializer_class(data=self.request.query_params)
+            serializer = serializer_class(data=self.request.query_params, **kwargs)
         serializer.is_valid(raise_exception=True)
         return serializer.validated_data
 
@@ -142,14 +148,37 @@ class ViewSet(viewsets.ViewSet):
             data[attr] = str(errors[0])
         return Response(data, status=status.HTTP_422_UNPROCESSABLE_ENTITY)
 
-    def check_is_valid(self, serializer_key=None):
+    def check_is_valid(self, **kwargs):
+        """
+        Validate request data (throw exception if invalid) and return validated data.
+
+        Args:
+            kwargs: supported values are :
+                    - serializer_key(None|str) : serializer to use,
+                        if not provided default is "<action name>_validation"
+                    - context(None|dict) : to pass context to serializer
+                        (in the methods of the serializer, the context can be accessed
+                         with statement "self.context")
+        Returns:
+            dict
+        """
         try:
-            validated_data = self.get_validated_data(serializer_key)
+            validated_data = self.get_validated_data(**kwargs)
         except ValidationError as e:
             errors = self._simplify_errors(e.detail)
             raise exceptions.ValidationError(errors)
         return dict(validated_data)
 
+    def check_is_list_valid(self, serializer_key=None):
+        try:
+            validated_data = self.get_validated_data(
+                serializer_key=serializer_key, many=True
+            )
+        except ValidationError as e:
+            errors = self._simplify_errors(e.detail)
+            raise exceptions.ValidationError(errors)
+        return list(validated_data)
+
     @action(methods=["post"], detail=False)
     def validate(self, request):
         """
