@@ -42,3 +42,11 @@ class DictService(AbstractService):
             mixed
         """
         return d[list(d.keys())[-1]]
+
+    @classmethod
+    def remap_keys(cls, d: dict, remap_keys: dict) -> dict:
+        """remap a dictionnary keys and keep only key found in remap_keys"""
+        remaped = {}
+        for old, new in remap_keys.items():
+            remaped[new] = d[old]
+        return remaped
