@@ -61,7 +61,8 @@ class TestAbstractImportService(TestCaseMixin):
         self.mock_abstract_methods[0]["return_value"] = self.excel_mapping
         with service_test_helper.mock_services(self.mock_abstract_methods) as m:
             import_report = AbstractImportService.import_file(
-                self.get_datasets_dir("excel/Excel2010.xlsx")
+                self.get_datasets_dir("excel/Excel2010.xlsx"),
+                context={"context_key_1": "context_value_1"},
             )
         assert import_report == "import_report"
         self.assert_equals_resultset(self.get_mock_calls(m))
