@@ -1,9 +1,11 @@
 from django.conf import settings
 from w.services.technical.google_map_service import GoogleMapService
 from w.tests.mixins.testcase_mixin import TestCaseMixin
+import os
 
 TEST_URL = "ma grosse adresses avec # des caratères à la con !$"
 TEST_PLACE_ID = "ChIJN1t_tDeuEmsRUsoyG83frY4"
+API_KEY = str(os.getenv("GOOGLE_MAP_SECRET"))
 
 
 class TestGMapService(TestCaseMixin):
@@ -12,7 +14,7 @@ class TestGMapService(TestCaseMixin):
         assert (
             url == "https://maps.googleapis.com/maps/api/geocode/json?address="
             "ma+grosse+adresses+avec+%23+des+carat%C3%A8res+%C3%A0+la+con+"
-            "%21%24&key=AIzaSyAYU9lXqmmetI3s7feQi_Yc6_f7KGvVPz4"
+            f"%21%24&key={API_KEY}"
         )
 
     def test_geocode_service(self):
@@ -31,7 +33,7 @@ class TestGMapService(TestCaseMixin):
         assert (
             url == "https://maps.googleapis.com/maps/api/place/queryautocomplete/json?"
             "input=ma+grosse+adresses+avec+%23+des+carat%C3%A8res+%C3%A0+la+con+%21%24"
-            "&key=AIzaSyAYU9lXqmmetI3s7feQi_Yc6_f7KGvVPz4&langage=fr&components=country"
+            f"&key={API_KEY}&langage=fr&components=country"
             "%3Afr%7Ccountry%3Ach%7Ccountry%3Abe%7Ccountry%3Ade%7Ccountry%3Aes"
             "&sessiontoken=mysession_token"
         )
@@ -52,10 +54,14 @@ class TestGMapService(TestCaseMixin):
         url = GoogleMapService.build_place_detail_url(TEST_PLACE_ID)
         assert (
             url == "https://maps.googleapis.com/maps/api/place/details/json?"
-            "place_id=ChIJN1t_tDeuEmsRUsoyG83frY4&key=AIzaSyAYU9lXqmmetI3s7feQi_Yc6_"
-            "f7KGvVPz4&fields=geometry,formatted_address,place_id"
+            "place_id=ChIJN1t_tDeuEmsRUsoyG83frY4&"
+            f"key={API_KEY}&fields=geometry,formatted_address,place_id"
         )
 
     def test_get_place_detail(self):
         resp = GoogleMapService.get_place_detail(TEST_PLACE_ID)
         self.assert_equals_resultset(resp)
+
+    def test_search_by_phone_number(self):
+        response = GoogleMapService.search_by_phone_number("09 72 37 89 11")
+        self.assert_equals_resultset(response)
